#include <mcrypt.h>
#include <stdio.h>
#include <strings.h>

/* Prints plaintext and ciphertext in hex for all the algorithms */

main() {

int td,i,j,len;
unsigned char keyword[]="                ";
unsigned char plaintext[]="        "; 
unsigned char ciphertext[20];
char *name;


  for (i=0;i<=150;i++) {

   td = init_mcrypt_ecb(i, keyword, sizeof(keyword));
   if (td<0) continue; 

   name=get_algorithms_name(i);
   if (name==NULL) continue;
   printf ("\nAlgorithm: %s\n",name);
   free(name);


   bzero(ciphertext,sizeof(ciphertext));
   strcpy(ciphertext,plaintext);

   printf ("plaintext:  ");
   for (j=0; j<mcrypt_get_block_size(i); j++) {
     printf("%.2x", ciphertext[j]);
   }
   

   if (sizeof(keyword)>get_key_size(i)) {
    len=get_key_size(i);
   }
   else {
    len=sizeof(keyword);
   }
   
   printf ("\nkeyword:    ");
   for (j=0; j<len; j++) {
     printf("%.2x", keyword[j]);
   }   

   mcrypt_ecb( td, ciphertext, mcrypt_get_block_size(i));

   printf ("\nciphertext: ");
   for (j=0; j<mcrypt_get_block_size(i); j++) {
     printf("%.2x", ciphertext[j]);
   }
   printf("\n");

   end_mcrypt_ecb(td);

  }

}